# eric7.QScintilla.SpellingDictionaryEditDialog

Module implementing a dialog to edit the various spell checking dictionaries.

### Global Attributes

None

### Classes

SpellingDictionaryEditDialog | Class implementing a dialog to edit the various spell checking dictionaries.

### Functions

None

## SpellingDictionaryEditDialog

Class implementing a dialog to edit the various spell checking dictionaries.

### Derived from

QDialog, Ui_SpellingDictionaryEditDialog

### Class Attributes

None

### Class Methods

None

### Methods

SpellingDictionaryEditDialog | Constructor
getData | Public method to get the data.
on_addButton_clicked | Private slot to handle adding an entry.

### Static Methods

None

#### SpellingDictionaryEditDialog (Constructor)

SpellingDictionaryEditDialog(data, info, parent=None)

Constructor

data (str)
  contents to be edited
info (str)
  info string to show at the header
parent (QWidget)
  reference to the parent widget

#### SpellingDictionaryEditDialog.getData

getData()

Public method to get the data.

Return:
  data of the dialog

Return Type:
  str

#### SpellingDictionaryEditDialog.on_addButton_clicked

on_addButton_clicked()

Private slot to handle adding an entry.

Up